==> pathfinding-algorithms-1.0.8.tgz: package/README.md <==
<h1>Pathfinding Algorithms</h1>

Hello there! This a package based on Javascript implementations of pathfinding algorithms we made as a part of our college project.<br/>

This can be used with any web application that requires any kind of maze solving or pathfinding in general, we've introduced DFS, BFS, Dijkstra and A\* algorithms in the first publish.<br/>

<h2>How to use?</h2>
<div>Step 1: Run <code>npm install pathfinding-algorithms</code> in the root directory.</div>
<div>Step 2: Import algorithms and use. That's it. See use cases.</div>

<h2>Next steps</h2>
<div>Import classes <code>import {dfs, bfs, astar, dijkstra} from 'pathfinding-algorithms'</div>

<h1>Running Algorithms for Pathfinding simulations</h1>

<h2>Arguments</h2>
<ul>
    <li>grid: grid is a 2D array or array of arrays of object of prototype <br/>
    <code>
        {
            weight: Number (for unweighted => put anything),
            isWall: Boolean
        }
    </code>
    </li>
    <li>
        start: String (`${start_cell_row}`_${start_cell_column})
    </li>
    <li>
        end: String (`${end_cell_row}`_${end_cell_column})
    </li>
</ul>
<code>

</code>

<code>
    function runBFS() {
        let bfsGrid = new bfsGraph(start, end, grid);
        let { path, exploredNodes } = bfsGrid.startAlgorithm();
    }

    function runDFS() {
        let dfsGrid = new dfsGraph(start, end, grid);
        let { path, exploredNodes } = dfsGrid.startAlgorithm();
    }

    function runDjikstra() {
        let djikstraGrid = new DjikstraGraph(start, end, grid);
        let { path, exploredNodes } = djikstraGrid.startAlgorithm();
    }

    function runAstar() {
        let astarGrid = new AstarGraph(start, end, grid);
        let { exploredNodes, path } = astarGrid.startAlgorithm();
    }

</code>

==> pathfinding-algorithms-1.0.9.tgz: package/README.md <==
<h1>Pathfinding Algorithms</h1>

Hello there! This a package based on Javascript implementations of pathfinding algorithms we made as a part of our college project.<br/>

This can be used with any web application that requires any kind of maze solving or pathfinding in general, we've introduced DFS, BFS, Dijkstra and A\* algorithms in the first publish.<br/>

<h2>How to use?</h2>
<div>Step 1: Run <code>npm install pathfinding-algorithms</code> in the root directory.</div>
<div>Step 2: Import algorithms and use. That's it. See use cases.</div>

<h2>Next steps</h2>
<div>Import classes <code>import {dfs, bfs, astar, dijkstra} from 'pathfinding-algorithms'</div>

<h1>Running Algorithms for Pathfinding simulations</h1>

<h2>Arguments</h2>
<ul>
    <li>grid: grid is a 2D array or array of arrays of object of prototype <br/>
    <code>
        {
            weight: Number (for unweighted => put anything),
            isWall: Boolean
        }
    </code>
    </li>
    <li>
        start: String (`${start_cell_row}`_${start_cell_column})
    </li>
    <li>
        end: String (`${end_cell_row}`_${end_cell_column})
    </li>
</ul>
<code>

</code>

<code>
    function runBFS() {
        let bfsGrid = new bfs(start, end, grid);
        let { path, exploredNodes } = bfsGrid.startAlgorithm();
    }
</code>
<code>
    function runDFS() {
        let dfsGrid = new dfs(start, end, grid);
        let { path, exploredNodes } = dfsGrid.startAlgorithm();
    }
</code>
<code>
    function runDjikstra() {
        let djikstraGrid = new djikstra(start, end, grid);
        let { path, exploredNodes } = djikstraGrid.startAlgorithm();
    }
</code>
<code>
    function runAstar() {
        let astarGrid = new astar(start, end, grid);
        let { exploredNodes, path } = astarGrid.startAlgorithm();
    }
</code>
